wildfly-py
=========

This package provides Python binding for the WildFly Management API.

Installation
------------

You can install stable version wildfly-py from PyPi.
```bash
pip install wildfly-py
```

You can install development version from GitHub.

```bash
pip install  git+git://github.com/cenx-cf/wildfly-py
```

Documentation
------------

Full documentation is hosted on [ReadTheDocs](http://wildfly-py.readthedocs.io/).
Sources are available in the [docs](docs/) directory.


License
-------

The project is licensed under the [Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0)

